@@ -16,6 +16,7 @@ sub pack {
 		if(exists $data->{max_files_cnt}) {
 			$p->pack(J => 1		=> $data->{max_files_cnt});
 			if(exists $data->{name}) {
+				$p->pack(J => 1	=> !! $data->{is_done});
 				$p->pack(a => '*' => $data->{name});
 			}
 		}
@@ -24,6 +25,19 @@ sub pack {
 	return $p->data;
 }
 
+sub unpack_format_v1 {
+	my($self, $data) = @_;
+	
+	my $p = $self->packer($data);
+	
+	return {
+		id				=> $p->unpack(J => 1),
+		files_cnt		=> $p->unpack(J => 1),
+		max_files_cnt	=> $p->unpack(J => 1),
+		name			=> $p->unpack(a => '*'),
+	};
+}
+
 sub unpack {
 	my($self, $data) = @_;
 	
@@ -33,8 +47,9 @@ sub unpack {
 		id				=> $p->unpack(J => 1),
 		files_cnt		=> $p->unpack(J => 1),
 		max_files_cnt	=> $p->unpack(J => 1),
+		is_done			=> $p->unpack(J => 1),
 		name			=> $p->unpack(a => '*'),
-	};		
+	};
 }
 
 1;
